# Web server that controls a Toika dobby loom

This server is intended to allow you to control your loom from any phone, tablet or other device that has wifi and a web browser.

For documentation (usage and installation instructions) see https://r-owen.github.io/toika_loom_server/
